@@ -12,15 +12,19 @@
 #
 
 PG15_EARLIEST = "15.10"
-PG15_LATEST = "15.13"
+PG15_LATEST = "15.14"
 PG15_ABI_MIN = "15.10"
 
 PG16_EARLIEST = "16.6"
-PG16_LATEST = "16.9"
+PG16_LATEST = "16.10"
 PG16_ABI_MIN = "16.6"
 
 PG17_EARLIEST = "17.2"
-PG17_LATEST = "17.5"
+PG17_LATEST = "17.6"
 PG17_ABI_MIN = "17.2"
 
-PG_LATEST = [PG15_LATEST, PG16_LATEST, PG17_LATEST]
+PG18_EARLIEST = "18.0"
+PG18_LATEST = "18.0"
+PG18_ABI_MIN = "18.0"
+
+PG_LATEST = [PG15_LATEST, PG16_LATEST, PG17_LATEST, PG18_LATEST]
