@@ -80,7 +80,6 @@ typedef struct CrossModuleFunctions
 	void (*set_rel_pathlist_dml)(PlannerInfo *, RelOptInfo *, Index, RangeTblEntry *, Hypertable *);
 	void (*set_rel_pathlist_query)(PlannerInfo *, RelOptInfo *, Index, RangeTblEntry *,
 								   Hypertable *);
-	bool (*process_explain_def)(DefElem *def);
 
 	/* gapfill */
 	PGFunction gapfill_marker;
@@ -95,9 +94,6 @@ typedef struct CrossModuleFunctions
 	PGFunction reorder_chunk;
 	PGFunction move_chunk;
 
-	DDLResult (*ddl_command_start)(ProcessUtilityArgs *args);
-	void (*ddl_command_end)(EventTriggerData *trigdata);
-
 	/* Vectorized queries */
 	void (*tsl_postprocess_plan)(PlannedStmt *stmt);
 
@@ -107,15 +103,14 @@ typedef struct CrossModuleFunctions
 	PGFunction finalize_agg_ffunc;
 	DDLResult (*process_cagg_viewstmt)(Node *stmt, const char *query_string, void *pstmt,
 									   WithClauseResult *with_clause_options);
-	PGFunction continuous_agg_invalidation_trigger;
-	void (*continuous_agg_call_invalidation_trigger)(int32 hypertable_id, Relation chunk_rel,
-													 HeapTuple chunk_tuple,
-													 HeapTuple chunk_newtuple, bool update);
 	PGFunction continuous_agg_refresh;
 	PGFunction continuous_agg_process_hypertable_invalidations;
 	void (*continuous_agg_invalidate_raw_ht)(const Hypertable *raw_ht, int64 start, int64 end);
 	void (*continuous_agg_invalidate_mat_ht)(const Hypertable *raw_ht, const Hypertable *mat_ht,
 											 int64 start, int64 end);
+	void (*continuous_agg_dml_invalidate)(int32 hypertable_id, Relation chunk_rel,
+										  HeapTuple chunk_tuple, HeapTuple chunk_newtuple,
+										  bool update);
 	void (*continuous_agg_update_options)(ContinuousAgg *cagg,
 										  WithClauseResult *with_clause_options);
 	PGFunction continuous_agg_validate_query;
@@ -123,6 +118,7 @@ typedef struct CrossModuleFunctions
 	PGFunction continuous_agg_get_bucket_function_info;
 	PGFunction continuous_agg_migrate_to_time_bucket;
 	PGFunction cagg_try_repair;
+	PGFunction continuous_agg_read_invalidation_record;
 
 	PGFunction compressed_data_send;
 	PGFunction compressed_data_recv;
@@ -139,11 +135,8 @@ typedef struct CrossModuleFunctions
 	void (*decompress_batches_for_insert)(ChunkInsertState *state, TupleTableSlot *slot);
 	void (*init_decompress_state_for_insert)(ChunkInsertState *state, TupleTableSlot *slot);
 	bool (*decompress_target_segments)(ModifyHypertableState *ht_state);
-	int (*hypercore_decompress_update_segment)(Relation relation, const ItemPointer ctid,
-											   TupleTableSlot *slot, Snapshot snapshot,
-											   ItemPointer new_tid);
 
-	void (*compression_enable)(Hypertable *ht, WithClauseResult *with_clause_options);
+	void (*columnstore_setup)(Hypertable *ht, WithClauseResult *with_clause_options);
 	RowCompressor *(*compressor_init)(Relation in_rel, BulkWriter **bulk_writer, bool sort);
 	void (*compressor_add_slot)(RowCompressor *compressor, BulkWriter *bulk_writer,
 								TupleTableSlot *slot);
@@ -168,7 +161,10 @@ typedef struct CrossModuleFunctions
 	PGFunction array_compressor_finish;
 	PGFunction bool_compressor_append;
 	PGFunction bool_compressor_finish;
+	PGFunction uuid_compressor_append;
+	PGFunction uuid_compressor_finish;
 	PGFunction bloom1_contains;
+	PGFunction (*bloom1_get_hash_function)(Oid type, FmgrInfo **finfo);
 
 	PGFunction create_chunk;
 	PGFunction show_chunk;
@@ -178,10 +174,6 @@ typedef struct CrossModuleFunctions
 	PGFunction recompress_chunk_segmentwise;
 	PGFunction get_compressed_chunk_index_for_recompression;
 
-	PGFunction hypercore_handler;
-	PGFunction hypercore_proxy_handler;
-	PGFunction is_compressed_tid;
-
 	void (*preprocess_query_tsl)(Query *parse, int *cursor_opts);
 	PGFunction merge_chunks;
 	PGFunction split_chunk;
