@@ -28,6 +28,7 @@ extern bool ts_guc_enable_constraint_exclusion;
 extern bool ts_guc_enable_cagg_reorder_groupby;
 extern TSDLLEXPORT bool ts_guc_enable_cagg_window_functions;
 extern TSDLLEXPORT int ts_guc_cagg_max_individual_materializations;
+extern TSDLLEXPORT bool ts_guc_enable_cagg_wal_based_invalidation;
 extern TSDLLEXPORT int ts_guc_cagg_wal_batch_size;
 extern TSDLLEXPORT int ts_guc_cagg_low_work_mem;
 extern TSDLLEXPORT int ts_guc_cagg_high_work_mem;
@@ -43,6 +44,9 @@ extern TSDLLEXPORT bool ts_guc_enable_dml_decompression_tuple_filtering;
 extern bool ts_guc_enable_direct_compress_copy;
 extern bool ts_guc_enable_direct_compress_copy_sort_batches;
 extern bool ts_guc_enable_direct_compress_copy_client_sorted;
+extern bool ts_guc_enable_direct_compress_insert;
+extern bool ts_guc_enable_direct_compress_insert_sort_batches;
+extern bool ts_guc_enable_direct_compress_insert_client_sorted;
 extern TSDLLEXPORT bool ts_guc_enable_compressed_direct_batch_delete;
 extern TSDLLEXPORT int ts_guc_max_tuples_decompressed_per_dml;
 extern TSDLLEXPORT bool ts_guc_enable_transparent_decompression;
