@@ -59,11 +59,6 @@ static const WithClauseDefinition continuous_aggregate_with_clause_def[] = {
         .arg_names = {"compress_chunk_interval", "compress_chunk_time_interval", NULL},
          .type_id = INTERVALOID,
     },
-	[CreateMaterializedViewFlagInvalidateUsing] = {
-        .arg_names = {"invalidate_using", NULL},
-		.type_id = TEXTOID,
-		.default_val = (Datum) 0,
-	},
 };
 
 WithClauseResult *
